Deep Quokka
Deep Quokka is Deeplearning framwork created to study deeplearning.it aims to be a fast deep learning framework.However,don’t apply it to real project yet.
For the most up to date version of this code,plase see https://github.com/kyunghyunHan/deep_quokka
Backends